@@ -1,13 +1,18 @@
 #!/usr/bin/env python
+# coding: utf-8
+from __future__ import unicode_literals
 
 from collections import defaultdict
+from datetime import datetime
+from optparse import make_option
+
+from boto.ses import SESConnection
 
-import boto3
 from django.core.management.base import BaseCommand
 
-from django_ses import settings
 from django_ses.models import SESStat
 from django_ses.views import stats_to_list
+from django_ses import settings
 
 
 def stat_factory():
@@ -26,13 +31,9 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
 
-        connection = boto3.client(
-            'ses',
+        connection = SESConnection(
             aws_access_key_id=settings.ACCESS_KEY,
             aws_secret_access_key=settings.SECRET_KEY,
-            region_name=settings.AWS_SES_REGION_NAME,
-            endpoint_url=settings.AWS_SES_REGION_ENDPOINT_URL,
-            config=settings.AWS_SES_CONFIG,
         )
         stats = connection.get_send_statistics()
         data_points = stats_to_list(stats, localize=False)
@@ -43,7 +44,7 @@ class Command(BaseCommand):
             bounces = int(data['Bounces'])
             complaints = int(data['Complaints'])
             rejects = int(data['Rejects'])
-            date = data['Timestamp'].date()
+            date = data['Timestamp'].split('T')[0]
             stats_dict[date]['delivery_attempts'] += attempts
             stats_dict[date]['bounces'] += bounces
             stats_dict[date]['complaints'] += complaints
@@ -57,7 +58,7 @@ class Command(BaseCommand):
                     'bounces': v['bounces'],
                     'complaints': v['complaints'],
                     'rejects': v['rejects'],
-                })
+            })
 
             # If statistic is not new, modify data if values are different
             if not created and stat.delivery_attempts != v['delivery_attempts']:
