@@ -1,6 +1,11 @@
+# coding: utf-8
+from __future__ import unicode_literals
+
 from django.db import models
+from django.utils.encoding import python_2_unicode_compatible
 
 
+@python_2_unicode_compatible
 class SESStat(models.Model):
     date = models.DateField(unique=True, db_index=True)
     delivery_attempts = models.PositiveIntegerField()
