@@ -1,40 +1,41 @@
+# coding: utf-8
+from __future__ import unicode_literals
+
 import base64
 import logging
-import warnings
-from builtins import str as text
-from builtins import bytes
-from io import StringIO
-
-from django_ses.deprecation import RemovedInDjangoSES20Warning
-
-from urllib.parse import urlparse
-from urllib.request import urlopen
-from urllib.error import URLError
 
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.encoding import smart_str
+from django.utils.six.moves import urllib
+
+try:
+    from django.utils.six.moves import cStringIO
+    StringIO = cStringIO.StringIO
+except (ImportError, AttributeError):
+    from django.utils.six import StringIO
+
 from django_ses import settings
 
 logger = logging.getLogger(__name__)
 
-
-class EventMessageVerifier(object):
+class BounceMessageVerifier(object):
     """
-    A utility class for validating event messages
+    A utility class for validating bounce messages
 
     See: http://docs.amazonwebservices.com/sns/latest/gsg/SendMessageToHttp.verify.signature.html
     """
 
-    def __init__(self, notification):
+    def __init__(self, bounce_dict):
         """
-        Creates a new event message from the given dict.
+        Creates a new bounce message from the given dict.
         """
-        self._data = notification
+        self._data = bounce_dict
         self._verified = None
 
     def is_verified(self):
         """
-        Verifies an SES event message.
+        Verifies an SES bounce message.
+
         """
         if self._verified is None:
             signature = self._data.get('Signature')
@@ -43,7 +44,7 @@ class EventMessageVerifier(object):
                 return self._verified
 
             # Decode the signature from base64
-            signature = bytes(base64.b64decode(signature))
+            signature = base64.b64decode(signature)
 
             # Get the message to sign
             sign_bytes = self._get_bytes_to_sign()
@@ -70,17 +71,17 @@ class EventMessageVerifier(object):
     @property
     def certificate(self):
         """
-        Retrieves the certificate used to sign the event message.
+        Retrieves the certificate used to sign the bounce message.
 
         TODO: Cache the certificate based on the cert URL so we don't have to
-        retrieve it for each event message. *We would need to do it in a
+        retrieve it for each bounce message. *We would need to do it in a
         secure way so that the cert couldn't be overwritten in the cache*
         """
         if not hasattr(self, '_certificate'):
             cert_url = self._get_cert_url()
             # Only load certificates from a certain domain?
             # Without some kind of trusted domain check, any old joe could
-            # craft a event message and sign it using his own certificate
+            # craft a bounce message and sign it using his own certificate
             # and we would happily load and verify it.
 
             if not cert_url:
@@ -90,20 +91,12 @@ class EventMessageVerifier(object):
             try:
                 import requests
             except ImportError:
-                raise ImproperlyConfigured(
-                    "`requests` is required for event message verification. "
-                    "Please consider installing the `django-ses` with the "
-                    "`event` extra - e.g. `pip install django-ses[events]`."
-                )
+                raise ImproperlyConfigured("requests is required for bounce message verification.")
 
             try:
                 import M2Crypto
             except ImportError:
-                raise ImproperlyConfigured(
-                    "`M2Crypto` is required for event message verification. "
-                    "Please consider installing the `django-ses` with the "
-                    "`event` extra - e.g. `pip install django-ses[events]`."
-                )
+                raise ImproperlyConfigured("M2Crypto is required for bounce message verification.")
 
             # We use requests because it verifies the https certificate
             # when retrieving the signing certificate. If https was somehow
@@ -122,22 +115,22 @@ class EventMessageVerifier(object):
             except M2Crypto.X509.X509Error as e:
                 logger.warning('Could not load certificate from %s: "%s"', cert_url, e)
                 self._certificate = None
-
+            
         return self._certificate
 
     def _get_cert_url(self):
         """
         Get the signing certificate URL.
-        Only accept urls that match the domains set in the
-        AWS_SNS_EVENT_CERT_TRUSTED_DOMAINS setting. Sub-domains
+        Only accept urls that match the domains set in the 
+        AWS_SNS_BOUNCE_CERT_TRUSTED_DOMAINS setting. Sub-domains
         are allowed. i.e. if amazonaws.com is in the trusted domains
         then sns.us-east-1.amazonaws.com will match.
         """
         cert_url = self._data.get('SigningCertURL')
         if cert_url:
             if cert_url.startswith('https://'):
-                url_obj = urlparse(cert_url)
-                for trusted_domain in settings.EVENT_CERT_DOMAINS:
+                url_obj = urllib.parse.urlparse(cert_url)
+                for trusted_domain in settings.BOUNCE_CERT_DOMAINS:
                     parts = trusted_domain.split('.')
                     if url_obj.netloc.split('.')[-len(parts):] == parts:
                         return cert_url
@@ -179,73 +172,22 @@ class EventMessageVerifier(object):
             # Unrecognized type
             logger.warning('Unrecognized SNS message Type: "%s"', msg_type)
             return None
-
+        
         outbytes = StringIO()
         for field_name in fields_to_sign:
             field_value = smart_str(self._data.get(field_name, ''),
                                     errors="replace")
             if field_value:
-                outbytes.write(text(field_name))
-                outbytes.write(text("\n"))
-                outbytes.write(text(field_value))
-                outbytes.write(text("\n"))
-
-        response = outbytes.getvalue()
-        return bytes(response, 'utf-8')
-
-
-def BounceMessageVerifier(*args, **kwargs):
-    warnings.warn(
-        'utils.BounceMessageVerifier is deprecated. It is renamed to EventMessageVerifier.',
-        RemovedInDjangoSES20Warning,
-    )
-
-    # parameter name is renamed from bounce_dict to notification.
-    if 'bounce_dict' in kwargs:
-        kwargs['notification'] = kwargs['bounce_dict']
-        del kwargs['bounce_dict']
-
-    return EventMessageVerifier(*args, **kwargs)
-
-
-def verify_event_message(notification):
-    """
-    Verify an SES/SNS event notification message.
-    """
-    verifier = EventMessageVerifier(notification)
-    return verifier.is_verified()
-
+                outbytes.write(field_name)
+                outbytes.write("\n")
+                outbytes.write(field_value)
+                outbytes.write("\n")
+         
+        return outbytes.getvalue()
 
 def verify_bounce_message(msg):
     """
-    Verify an SES/SNS bounce(event) notification message.
+    Verify an SES/SNS bounce notification message.
     """
-    warnings.warn(
-        'utils.verify_bounce_message is deprecated. It is renamed to verify_event_message.',
-        RemovedInDjangoSES20Warning,
-    )
-    return verify_event_message(msg)
-
-
-def confirm_sns_subscription(notification):
-    logger.info(
-        'Received subscription confirmation: TopicArn: %s',
-        notification.get('TopicArn'),
-        extra={
-            'notification': notification,
-        },
-    )
-
-    # Get the subscribe url and hit the url to confirm the subscription.
-    subscribe_url = notification.get('SubscribeURL')
-    try:
-        urlopen(subscribe_url).read()
-    except URLError as e:
-        # Some kind of error occurred when confirming the request.
-        logger.error(
-            'Could not confirm subscription: "%s"', e,
-            extra={
-                'notification': notification,
-            },
-            exc_info=True,
-        )
+    verifier = BounceMessageVerifier(msg)
+    return verifier.is_verified()
