@@ -1,11 +1,10 @@
-from django.core.mail import EmailMessage
 from django.http import HttpResponse
-from django.shortcuts import render
-
+from django.core.urlresolvers import reverse
+from django.core.mail import send_mail, EmailMessage
+from django.shortcuts import render_to_response
 
 def index(request):
-    return render(request, 'index.html')
-
+    return render_to_response('index.html')
 
 def send_email(request):
     if request.method == 'POST':
@@ -25,4 +24,5 @@ def send_email(request):
 
         return HttpResponse('Email sent :)')
     else:
-        return render(request, 'send-email.html')
+        return render_to_response('send-email.html')
+
