@@ -1,7 +1,10 @@
+# coding: utf-8
+from __future__ import unicode_literals
+
 from django.test import TestCase
 from django.conf import settings
-from tests.utils import unload_django_ses
 
+from tests.utils import unload_django_ses
 
 class SettingsImportTest(TestCase):
     def test_aws_access_key_given(self):
@@ -20,8 +23,4 @@ class SettingsImportTest(TestCase):
         self.assertEqual(django_ses.settings.ACCESS_KEY, settings.AWS_SES_ACCESS_KEY_ID)
         self.assertEqual(django_ses.settings.SECRET_KEY, settings.AWS_SES_SECRET_ACCESS_KEY)
 
-    def test_ses_configuration_set_given(self):
-        settings.AWS_SES_CONFIGURATION_SET = "test-set"
-        unload_django_ses()
-        import django_ses
-        self.assertEqual(django_ses.settings.AWS_SES_CONFIGURATION_SET, settings.AWS_SES_CONFIGURATION_SET)
+
